/*-- ================================================================== --
-- SISTEMA         : GESTAO DE VENDAS                                   --
-- DATA DA CRIAO : 06/12/2006                                         --
-- CRIAO         : LUCIANA CORREA                                     --
-- OBJETIVOS       : GRAVA VENDA PARA T&TEL                             --
-- ==================================================================== --
*/
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'GRAVA_VENDA_TTEL' AND
	        TYPE = 'P'                  AND
	        U.UID = O.UID               AND
	        U.NAME = USER)

   DROP PROCEDURE GRAVA_VENDA_TTEL
   GO

CREATE PROCEDURE GRAVA_VENDA_TTEL
  @P_CDFILIAL     VARCHAR(4),
  @P_CDCAIXA      VARCHAR(3),
  @P_CRACHA       VARCHAR(21),
  @P_CDOPERADOR   VARCHAR(12),
  @P_CDFAMILISALD VARCHAR(3),
  @P_QUANTIDADE   FLOAT,
  @P_PRECO        FLOAT,
  @P_CDPRODUTO    VARCHAR(10),
  @P_RETORNO      VARCHAR(50) OUTPUT

AS
BEGIN

   DECLARE @V_CDCLIENTE     VARCHAR(21);
   DECLARE @V_CDCONSUMIDOR  VARCHAR(21);
   DECLARE @V_NRSEQVENDA    VARCHAR(20);
   DECLARE @V_NRSEQTTEL     VARCHAR(50);
   DECLARE @V_CDEMPRESA     VARCHAR(02);
   DECLARE @V_CONTADOR1     VARCHAR(100);
   DECLARE @V_CONTADOR2     VARCHAR(100);
   DECLARE @V_CONTADOR3     VARCHAR(100);
   DECLARE @V_CDIMPOSTO     VARCHAR(2);
   DECLARE @V_ALIQUOTA      FLOAT;
   DECLARE @V_CDTIPORECE    VARCHAR(3);
   DECLARE @V_VRSALDCONFAM  FLOAT;
   DECLARE @V_VRSALDCONFAM_CRED FLOAT;   
   DECLARE @V_DATAATUAL     DATETIME;
   DECLARE @V_DTABERCAIX    DATETIME;
   DECLARE @V_NMPRODUTO     VARCHAR(60);
   DECLARE @V_CDLOJA        VARCHAR(10);
   DECLARE @V_NRSEQUMOVI    VARCHAR(20);
   DECLARE @INSERE_ABERTURA VARCHAR(01);
   DECLARE @V_EXISTESALDO   INTEGER;
   DECLARE @V_ERRO          VARCHAR(04);
   DECLARE @V_CDFILIAL      VARCHAR(04);
   DECLARE @V_CDCAIXA       VARCHAR(03);
   DECLARE @V_IDSALDNEGFAM  VARCHAR(01);
   DECLARE @V_CDSALDO       VARCHAR(03);
   DECLARE @V_VRSALDO       FLOAT;
   DECLARE @V_IDNEGFAM      VARCHAR(01);
   DECLARE @V_NRORDAPRSALD  VARCHAR(03);
   DECLARE @V_VRMOVEXTCONS  FLOAT;
   DECLARE @V_VRSALDCONEXT  FLOAT;
   DECLARE @V_VRSALDCONEXT_CRED FLOAT;
   DECLARE @V_TRANFERENCIA_OK VARCHAR(01);
   DECLARE @V_IDVERSALDCON  VARCHAR(01);
   DECLARE @V_LIMDEBCONS    FLOAT;
   DECLARE @V_VRSALDO_FAM1  FLOAT;
   DECLARE @V_VRMOVIMENTO   FLOAT;
   DECLARE @V_SALDO         FLOAT;

   SET @INSERE_ABERTURA = 'N';
   SET @P_RETORNO = 'ERRO';
   SET @V_TRANFERENCIA_OK = 'N';

   SET @V_DATAATUAL  = CAST(CONVERT(VARCHAR,GETDATE(),103) AS DATETIME);
   SET @V_DTABERCAIX = CAST(CONVERT(VARCHAR,GETDATE(),103)+' '+CONVERT(VARCHAR,GETDATE(),108) AS DATETIME);

   -- VALIDA A FILIAL
   SELECT @V_CDFILIAL = MAX(CDFILIAL)
   FROM   FILIAL
   WHERE  CDFILIAL = @P_CDFILIAL;
   IF (@V_CDFILIAL IS NULL) BEGIN
      SET @P_RETORNO = 'CODIGO DA FILIAL NAO ENCONTRADO';
      RETURN;
   END;

   -- VALIDA O CAIXA
   SELECT @V_CDCAIXA = MAX(CDCAIXA)
   FROM   CAIXA
   WHERE  CDFILIAL = @P_CDFILIAL
     AND  CDCAIXA  = @P_CDCAIXA;
   IF (@V_CDCAIXA IS NULL) BEGIN
      SET @P_RETORNO = 'CODIGO DO CAIXA NAO ENCONTRADO';
      RETURN;
   END;

   -- VALIDA O PRODUTO
   SELECT @V_NMPRODUTO = NMPRODUTO
   FROM   PRODUTO
   WHERE  CDPRODUTO = @P_CDPRODUTO
   IF (@V_NMPRODUTO IS NULL) BEGIN
      SET @P_RETORNO = 'CODIGO DO PRODUTO NAO ENCONTRADO';
      RETURN;
   END;

   -- VALIDA O CRACHA DO ALUNO E SELECIONA SE ELE PODE FICAR NEGATICO PARA QUALQUER FAMILIA
   SELECT @V_CDCLIENTE    = MAX(CDCLIENTE),
          @V_CDCONSUMIDOR = MAX(CDCONSUMIDOR),
          @V_IDVERSALDCON = MAX(IDVERSALDCON),
          @V_LIMDEBCONS   = MAX(ISNULL(VRLIMDEBCONS,0))
   FROM   CONSUMIDOR
   WHERE  CDIDCONSUMID = @P_CRACHA
   GROUP BY CDIDCONSUMID;
   IF (@V_CDCLIENTE IS NULL) BEGIN
      SET @P_RETORNO = 'CODIGO DO CRACHA NAO ENCONTRADO';
      RETURN;
   END;

   -- VALIDA A EMPRESA DA FILIAL
   SELECT @V_CDEMPRESA = CDEMPRESA
   FROM   FILIAL
   WHERE  CDFILIAL = @P_CDFILIAL;
   IF (@V_CDEMPRESA IS NULL) BEGIN
      SET @P_RETORNO = 'FALTA PARAMETRIZAR A EMPRESA DA FILIAL';
      RETURN;
   END;

   -- VALIDA O IMPOSTO DO PRODUTO
   SELECT @V_ALIQUOTA  = MAX(VRPEALIMPFIS),
          @V_CDIMPOSTO = MAX(CDIMPOSTO)
   FROM   ALIQIMPFIS
   WHERE  CDFILIAL  = @P_CDFILIAL
      AND CDPRODUTO = @P_CDPRODUTO
   GROUP BY CDFILIAL,CDPRODUTO;
   IF (@V_ALIQUOTA IS NULL) BEGIN
      SET @P_RETORNO = 'IMPOSTO NAO PARAMETRIZADO PARA O PRODUTO';
      RETURN;
   END;

   -- VALIDA O TIPO DE RECEBIMENTO CREDITO PESSOAL
   SELECT @V_CDTIPORECE = MAX(CDTIPORECE)
   FROM   TIPORECE
   WHERE  IDTIPORECE = '9'
   GROUP BY IDTIPORECE;
   IF (@V_CDTIPORECE IS NULL) BEGIN
      SET @P_RETORNO = 'TIPO RECEB. CRDITO PESSOAL NAO CADASTRADO';
      RETURN;
   END;

   -- BUSCA A LOJA DO CAIXA
   SELECT @V_CDLOJA = MAX(CDLOJA)
   FROM   CAIXA
   WHERE  CDFILIAL = @P_CDFILIAL
     AND  CDCAIXA  = @P_CDCAIXA;

   SET @V_CONTADOR1 = 'PEDIDOVENDA'+@P_CDFILIAL+@P_CDCAIXA;
   SET @V_CONTADOR2 = 'VENDATTEL'+@P_CDFILIAL;
   SET @V_CONTADOR3 = 'MOVCAIXA'+@P_CDFILIAL+@P_CDCAIXA+CONVERT(VARCHAR,@V_DTABERCAIX,103)+' '+CONVERT(VARCHAR,@V_DTABERCAIX,108);

   --PRINT @V_CONTADOR3; --PRINT @V_DTABERCAIX;

   EXECUTE NOVO_CODIGO @V_CONTADOR1,@V_NRSEQVENDA OUTPUT,1;
   EXECUTE NOVO_CODIGO @V_CONTADOR2,@V_NRSEQTTEL  OUTPUT,1;
   EXECUTE NOVO_CODIGO @V_CONTADOR3,@V_NRSEQUMOVI OUTPUT,1;

   SET @V_NRSEQVENDA = RIGHT(@V_NRSEQVENDA,10);
   SET @V_NRSEQUMOVI = RIGHT(@V_NRSEQUMOVI,10);
   SET @V_ERRO = '';

   BEGIN TRANSACTION;

   INSERT INTO TURCAIXA
    (CDFILIAL,CDCAIXA,DTABERCAIX,CDOPERADOR,DTFECHCAIX,CDOPERABER,CDOPERFECH,DTMOVTURCAIX,IDIMPTCAIXA)
   VALUES
    (@P_CDFILIAL, @P_CDCAIXA, @V_DTABERCAIX ,@P_CDOPERADOR,GETDATE(),@P_CDOPERADOR,@P_CDOPERADOR,@V_DATAATUAL,'N');
   IF @@ERROR <> 0 BEGIN
      SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA TURCAIXA',1,50);
      SET @V_ERRO = 'ERRO';
   END;

   INSERT INTO VENDA
     (CDFILIAL,CDCAIXA,NRSEQVENDA,CDCLIENTE,CDCONSUMIDOR,CDEMPRESA,DTVENDA,DTENTRVENDA,IDSITUVENDA,CDFILIALTUR,CDCAIXATUR,DTABERTUR,DTFECHAVENDA,CDOPERADOR,IDTIPOVENDA,TXOBSVENDA,CDLOJA,IDTPFORPGVEN,IDVENDEBCONS)
   VALUES
     (@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,@V_CDCLIENTE,@V_CDCONSUMIDOR,@V_CDEMPRESA,GETDATE(),@V_DATAATUAL,'O',@P_CDFILIAL,@P_CDCAIXA,@V_DTABERCAIX,GETDATE(),@P_CDOPERADOR,'I','VENDA ORIGINADA APLICATIVO T&TEL',@V_CDLOJA,'V','N');
   IF @@ERROR <> 0 BEGIN
      SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA VENDA',1,50);
      SET @V_ERRO = 'ERRO';
   END;

   INSERT INTO ITEMVENDA
     (CDFILIAL,CDCAIXA,NRSEQVENDA,NRSEQUITVEND,QTPRODVEND,VRUNITVEND,CDPRODUTO,CDFAMILISALD,CDLOJA)
   VALUES
     (@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'001',@P_QUANTIDADE,@P_PRECO,@P_CDPRODUTO,@P_CDFAMILISALD,@V_CDLOJA);
   IF @@ERROR <> 0 BEGIN
      SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA ITEMVENDA',1,50);
      SET @V_ERRO = 'ERRO';
   END;

   INSERT INTO ITVENDAIMPOS
     (CDFILIAL,CDCAIXA,NRSEQVENDA,NRSEQUITVEND,NRSEQITIMPOS,CDIMPOSTO,VRPEALPRODIT,VRIMPOPRODIT)
   VALUES
     (@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'001','001',@V_CDIMPOSTO,@V_ALIQUOTA,@V_ALIQUOTA*@P_PRECO*@P_QUANTIDADE/100);
   IF @@ERROR <> 0 BEGIN
      SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA ITVENDAIMPOS',1,50);
      SET @V_ERRO = 'ERRO';
   END;

   INSERT INTO MOVCAIXA
     (CDFILIAL, CDCAIXA, DTABERCAIX,NRSEQUMOVI,IDTIPOMOVIVE,DSMOVIVEND,VRMOVIVEND,NRSEQVENDA,CDTIPORECE,DTHRINCMOV,DTMOVIMCAIXA)
   VALUES
     (@P_CDFILIAL, @P_CDCAIXA, @V_DTABERCAIX ,@V_NRSEQUMOVI,'E','RECEBIMENTO VENDA T&TEL',(@P_QUANTIDADE*@P_PRECO),@V_NRSEQVENDA,@V_CDTIPORECE,GETDATE(),@V_DATAATUAL);
   IF @@ERROR <> 0 BEGIN
      SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA MOVCAIXA',1,50);
      SET @V_ERRO = 'ERRO';
   END;

   -- BUSCA O SALDO ATUAL DO ALUNO PARA A FAMILIA
   SET @V_VRSALDCONFAM = 0;
   SELECT @V_VRSALDCONFAM = ISNULL(MAX(VRSALDCONFAM),0)
   FROM   SALDOCONS
   WHERE CDCLIENTE    = @V_CDCLIENTE
     AND CDCONSUMIDOR = @V_CDCONSUMIDOR
     AND CDFAMILISALD = @P_CDFAMILISALD;

   SET @V_VRMOVEXTCONS = (@P_QUANTIDADE*@P_PRECO);

   -- SE O SALDO  SUFICIENTE
   IF @V_VRSALDCONFAM >= @V_VRMOVEXTCONS BEGIN

      -- INSERE O DBITO REFERENTE A VENDA
      INSERT INTO EXTRATOCONS
        (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS)
      VALUES
        (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,GETDATE(),'001',@V_CDTIPORECE,@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'Venda Caixa'+@P_CDCAIXA,@V_VRMOVEXTCONS,@V_VRSALDCONFAM-@V_VRMOVEXTCONS,'V',@V_DTABERCAIX,GETDATE(),'N');
      IF @@ERROR <> 0 BEGIN
         SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA EXTRATOCONS',1,50);
         SET @V_ERRO      = 'ERRO';
      END;

      SELECT @V_EXISTESALDO = COUNT(*)
      FROM SALDOCONS
      WHERE CDCLIENTE    = @V_CDCLIENTE
        AND CDCONSUMIDOR = @V_CDCONSUMIDOR
        AND CDFAMILISALD = @P_CDFAMILISALD;

      IF @V_EXISTESALDO > 0 BEGIN
         UPDATE SALDOCONS
         SET    VRSALDCONFAM = VRSALDCONFAM-@V_VRMOVEXTCONS
         WHERE CDCLIENTE    = @V_CDCLIENTE
           AND CDCONSUMIDOR = @V_CDCONSUMIDOR
           AND CDFAMILISALD = @P_CDFAMILISALD;
         IF @@ERROR <> 0 BEGIN
            SET @V_NRSEQTTEL = 'ERRO UPDATE TABELA EXTRATOCONS';
            SET @V_ERRO = 'ERRO';
         END;
      END ELSE BEGIN
         INSERT INTO SALDOCONS
           (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,VRSALDCONFAM)
         VALUES
           (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,0-@V_VRMOVEXTCONS);
         IF @@ERROR <> 0 BEGIN
            SET @V_NRSEQTTEL = 'ERRO INSERT TABELA EXTRATOCONS';
            SET @V_ERRO = 'ERRO';
         END;
      END;
   -- SALDO NO  SUFICIENTE
   END ELSE BEGIN
      -- SE O CONSUMIDOR TIVER LIMITE PARA FICAR NEGATIVO
      IF (@V_LIMDEBCONS > 0) BEGIN
         IF (@P_CDFAMILISALD = '001') BEGIN
            -- SE O FICA DENTRO DO VALOR LIMITE NECESSRIO
            IF ((@V_VRSALDCONFAM-@V_VRMOVEXTCONS) >= (@V_LIMDEBCONS*(-1))) BEGIN
               INSERT INTO EXTRATOCONS
                 (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS)
               VALUES
                 (@V_CDCLIENTE,@V_CDCONSUMIDOR,'001',GETDATE(),'001',@V_CDTIPORECE,@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'Venda Caixa'+@P_CDCAIXA,@V_VRMOVEXTCONS,@V_VRSALDCONFAM-@V_VRMOVEXTCONS,'V',@V_DTABERCAIX,GETDATE(),'N');
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA EXTRATOCONS',1,50);
                  SET @V_ERRO      = 'ERRO';
               END;

               SELECT @V_EXISTESALDO = COUNT(*)
               FROM SALDOCONS
               WHERE CDCLIENTE    = @V_CDCLIENTE
                 AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                 AND CDFAMILISALD = '001';

               IF @V_EXISTESALDO > 0 BEGIN
                  UPDATE SALDOCONS
                  SET    VRSALDCONFAM = VRSALDCONFAM-@V_VRMOVEXTCONS
                  WHERE CDCLIENTE    = @V_CDCLIENTE
                    AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                    AND CDFAMILISALD = '001';
                  IF @@ERROR <> 0 BEGIN
                     SET @V_NRSEQTTEL = 'ERRO UPDATE TABELA EXTRATOCONS';
                     SET @V_ERRO = 'ERRO';
                  END;
               END ELSE BEGIN
                  INSERT INTO SALDOCONS
                    (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,VRSALDCONFAM)
                  VALUES
                    (@V_CDCLIENTE,@V_CDCONSUMIDOR,'001',0-@V_VRMOVEXTCONS);
                  IF @@ERROR <> 0 BEGIN
                     SET @V_NRSEQTTEL = 'ERRO INSERT TABELA EXTRATOCONS';
                     SET @V_ERRO = 'ERRO';
                  END;
               END;
            END ELSE BEGIN
               SET @V_NRSEQTTEL = SUBSTRING('SALDO INSUFICIENTE DO CONSUMIDOR',1,50);
               SET @V_ERRO = 'ERRO';
            END;
         END ELSE BEGIN
            -- PEDE EMPRESTADO PARA A FAMLIA 001 - FIXO
            -- INSERE UM DBITO NA FAMILIA 001
            SET @V_VRSALDO_FAM1 = 0;
            SELECT @V_VRSALDO_FAM1 = ISNULL(MAX(VRSALDCONFAM),0)
            FROM   SALDOCONS
            WHERE CDCLIENTE    = @V_CDCLIENTE
              AND CDCONSUMIDOR = @V_CDCONSUMIDOR
              AND CDFAMILISALD = '001';

            IF ((@V_VRSALDO_FAM1-@V_VRMOVEXTCONS+@V_VRSALDCONFAM) >= (@V_LIMDEBCONS*(-1))) BEGIN

               IF @V_VRSALDCONFAM > 0 BEGIN
                  SET @V_VRMOVIMENTO = (@V_VRMOVEXTCONS-@V_VRSALDCONFAM);
                  SET @V_SALDO     = (@V_VRSALDO_FAM1-(@V_VRMOVEXTCONS-@V_VRSALDCONFAM));
               END ELSE BEGIN
                  SET @V_VRMOVIMENTO = @V_VRMOVEXTCONS;
                  SET @V_SALDO     = (@V_VRSALDO_FAM1-@V_VRMOVEXTCONS);
               END;
               INSERT INTO EXTRATOCONS
                  (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS)
               VALUES
                  (@V_CDCLIENTE,@V_CDCONSUMIDOR,'001',GETDATE(),'001',@V_CDTIPORECE,@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'Transf. Debito',@V_VRMOVIMENTO,@V_SALDO,'D',@V_DTABERCAIX,GETDATE(),'N');
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA EXTRATOCONS',1,50);
                  SET @V_ERRO      = 'ERRO';
               END;

               SELECT @V_EXISTESALDO = COUNT(*)
               FROM SALDOCONS
               WHERE CDCLIENTE    = @V_CDCLIENTE
                 AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                 AND CDFAMILISALD = '001';

               IF @V_EXISTESALDO > 0 BEGIN
                  UPDATE SALDOCONS
                  SET    VRSALDCONFAM = VRSALDCONFAM-@V_VRMOVIMENTO
                  WHERE CDCLIENTE    = @V_CDCLIENTE
                    AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                    AND CDFAMILISALD = '001';
                  IF @@ERROR <> 0 BEGIN
                     SET @V_NRSEQTTEL = 'ERRO UPDATE TABELA SALDOCONS';
                     SET @V_ERRO = 'ERRO';
                  END;
               END ELSE BEGIN
                  INSERT INTO SALDOCONS
                    (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,VRSALDCONFAM)
                  VALUES
                    (@V_CDCLIENTE,@V_CDCONSUMIDOR,'001',0-@V_VRMOVIMENTO);
                  IF @@ERROR <> 0 BEGIN
                     SET @V_NRSEQTTEL = 'ERRO INSERT TABELA SALDOCONS';
                     SET @V_ERRO = 'ERRO';
                  END;
               END;

               -- MOVIMENTACAO NA EXTRATOCONS CREDITO
               INSERT INTO EXTRATOCONS
                  (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS)
               VALUES
                  (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,GETDATE(),'002',@V_CDTIPORECE,@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'Transf. Credito',@V_VRMOVIMENTO,(@V_VRSALDCONFAM+@V_VRMOVIMENTO),'C',@V_DTABERCAIX,GETDATE(),'N');
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA EXTRATOCONS',1,50);
                  SET @V_ERRO      = 'ERRO';
               END;

               -- ATUALIZA O SALDOCONS DA FAMILIA DE CREDITO
               SELECT @V_EXISTESALDO = COUNT(*)
               FROM SALDOCONS
               WHERE CDCLIENTE    = @V_CDCLIENTE
                 AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                 AND CDFAMILISALD = @P_CDFAMILISALD;

               IF @V_EXISTESALDO > 0 BEGIN
                  UPDATE SALDOCONS
                  SET    VRSALDCONFAM = VRSALDCONFAM+@V_VRMOVIMENTO
                  WHERE  CDCLIENTE    = @V_CDCLIENTE
                    AND  CDCONSUMIDOR = @V_CDCONSUMIDOR
                    AND  CDFAMILISALD = @P_CDFAMILISALD;
                  IF @@ERROR <> 0 BEGIN
                     SET @V_NRSEQTTEL = 'ERRO UPDATE TABELA SALDOCONS';
                     SET @V_ERRO = 'ERRO';
                  END;
               END ELSE BEGIN
                  INSERT INTO SALDOCONS
                    (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,VRSALDCONFAM)
                  VALUES
                    (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,@V_VRMOVIMENTO);
                  IF @@ERROR <> 0 BEGIN
                     SET @V_NRSEQTTEL = 'ERRO INSERT TABELA SALDOCONS';
                     SET @V_ERRO = 'ERRO';
                  END;
               END;

               -- BUSCA O SALDO ATUALIZADO DO ALUNO DEPOIS DA TRANSF. DE CRDITO
               SET @V_VRSALDCONFAM_CRED = 0;
               SELECT @V_VRSALDCONFAM_CRED = ISNULL(MAX(VRSALDCONFAM),0)
               FROM   SALDOCONS
               WHERE CDCLIENTE    = @V_CDCLIENTE
                 AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                 AND CDFAMILISALD = @P_CDFAMILISALD;

               -- INSERE O DBITO REFERENTE A VENDA
               INSERT INTO EXTRATOCONS
                 (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS)
               VALUES
                 (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,GETDATE(),'001',@V_CDTIPORECE,@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'Venda Caixa'+@P_CDCAIXA,@V_VRMOVEXTCONS,@V_VRSALDCONFAM_CRED-@V_VRMOVEXTCONS,'V',@V_DTABERCAIX,GETDATE(),'N');
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA EXTRATOCONS',1,50);
                  SET @V_ERRO      = 'ERRO';
               END;

               SELECT @V_EXISTESALDO = COUNT(*)
               FROM SALDOCONS
               WHERE CDCLIENTE    = @V_CDCLIENTE
                 AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                 AND CDFAMILISALD = @P_CDFAMILISALD;

               IF @V_EXISTESALDO > 0 BEGIN
                  UPDATE SALDOCONS
                  SET    VRSALDCONFAM = @V_VRSALDCONFAM_CRED-@V_VRMOVEXTCONS
                  WHERE CDCLIENTE    = @V_CDCLIENTE
                    AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                    AND CDFAMILISALD = @P_CDFAMILISALD;
                  IF @@ERROR <> 0 BEGIN
                     SET @V_NRSEQTTEL = 'ERRO UPDATE TABELA EXTRATOCONS';
                     SET @V_ERRO = 'ERRO';
                  END;
               END ELSE BEGIN
                  INSERT INTO SALDOCONS
                    (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,VRSALDCONFAM)
                  VALUES
                    (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,0-@V_VRMOVEXTCONS);
                  IF @@ERROR <> 0 BEGIN
                     SET @V_NRSEQTTEL = 'ERRO INSERT TABELA EXTRATOCONS';
                     SET @V_ERRO = 'ERRO';
                  END;
               END;
            END ELSE BEGIN
               SET @V_NRSEQTTEL = SUBSTRING('SALDO INSUFICIENTE DO CONSUMIDOR',1,50);
               SET @V_ERRO = 'ERRO';
            END;
         END;
      END ELSE BEGIN
         -- PEDE EMPRESTADO PARA A FAMLIA 001 - FIXO
         -- INSERE UM DBITO NA FAMILIA 001
         SET @V_VRSALDO_FAM1 = 0;
         SELECT @V_VRSALDO_FAM1 = ISNULL(MAX(VRSALDCONFAM),0)
         FROM   SALDOCONS
         WHERE CDCLIENTE    = @V_CDCLIENTE
           AND CDCONSUMIDOR = @V_CDCONSUMIDOR
           AND CDFAMILISALD = '001';

         IF @V_VRSALDCONFAM > 0 BEGIN
            SET @V_VRMOVIMENTO = (@V_VRMOVEXTCONS-@V_VRSALDCONFAM);
            SET @V_SALDO     = (@V_VRSALDO_FAM1-(@V_VRMOVEXTCONS-@V_VRSALDCONFAM));
         END ELSE BEGIN
            SET @V_VRMOVIMENTO = @V_VRMOVEXTCONS;
            SET @V_SALDO     = (@V_VRSALDO_FAM1-@V_VRMOVEXTCONS);
         END;

         IF (@V_VRSALDO_FAM1 >= @V_VRMOVIMENTO) BEGIN

            INSERT INTO EXTRATOCONS
               (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS)
            VALUES
               (@V_CDCLIENTE,@V_CDCONSUMIDOR,'001',GETDATE(),'001',@V_CDTIPORECE,@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'Transf. Debito',@V_VRMOVIMENTO,@V_SALDO,'D',@V_DTABERCAIX,GETDATE(),'N');
            IF @@ERROR <> 0 BEGIN
               SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA EXTRATOCONS',1,50);
               SET @V_ERRO      = 'ERRO';
            END;

            SELECT @V_EXISTESALDO = COUNT(*)
            FROM SALDOCONS
            WHERE CDCLIENTE    = @V_CDCLIENTE
              AND CDCONSUMIDOR = @V_CDCONSUMIDOR
              AND CDFAMILISALD = '001';

            IF @V_EXISTESALDO > 0 BEGIN
               UPDATE SALDOCONS
               SET    VRSALDCONFAM = VRSALDCONFAM-@V_VRMOVIMENTO
               WHERE CDCLIENTE    = @V_CDCLIENTE
                 AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                 AND CDFAMILISALD = '001';
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = 'ERRO UPDATE TABELA SALDOCONS';
                  SET @V_ERRO = 'ERRO';
               END;
            END ELSE BEGIN
               INSERT INTO SALDOCONS
                 (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,VRSALDCONFAM)
               VALUES
                 (@V_CDCLIENTE,@V_CDCONSUMIDOR,'001',0-@V_VRMOVIMENTO);
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = 'ERRO INSERT TABELA SALDOCONS';
                  SET @V_ERRO = 'ERRO';
               END;
            END;

            -- MOVIMENTACAO NA EXTRATOCONS CREDITO
            INSERT INTO EXTRATOCONS
               (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS)
            VALUES
               (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,GETDATE(),'002',@V_CDTIPORECE,@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'Transf. Credito',@V_VRMOVIMENTO,(@V_VRSALDCONFAM+@V_VRMOVIMENTO),'C',@V_DTABERCAIX,GETDATE(),'N');
            IF @@ERROR <> 0 BEGIN
               SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA EXTRATOCONS',1,50);
               SET @V_ERRO      = 'ERRO';
            END;

            -- ATUALIZA O SALDOCONS DA FAMILIA DE CREDITO
            SELECT @V_EXISTESALDO = COUNT(*)
            FROM SALDOCONS
            WHERE CDCLIENTE    = @V_CDCLIENTE
              AND CDCONSUMIDOR = @V_CDCONSUMIDOR
              AND CDFAMILISALD = @P_CDFAMILISALD;

            IF @V_EXISTESALDO > 0 BEGIN
               UPDATE SALDOCONS
               SET    VRSALDCONFAM = VRSALDCONFAM+@V_VRMOVIMENTO
               WHERE  CDCLIENTE    = @V_CDCLIENTE
                 AND  CDCONSUMIDOR = @V_CDCONSUMIDOR
                 AND  CDFAMILISALD = @P_CDFAMILISALD;
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = 'ERRO UPDATE TABELA SALDOCONS';
                  SET @V_ERRO = 'ERRO';
               END;
            END ELSE BEGIN
               INSERT INTO SALDOCONS
                 (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,VRSALDCONFAM)
               VALUES
                 (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,@V_VRMOVIMENTO);
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = 'ERRO INSERT TABELA SALDOCONS';
                  SET @V_ERRO = 'ERRO';
               END;
            END;

            -- BUSCA O SALDO ATUALIZADO DO ALUNO DEPOIS DA TRANSF. DE CRDITO
            SET @V_VRSALDCONFAM_CRED = 0;
            SELECT @V_VRSALDCONFAM_CRED = ISNULL(MAX(VRSALDCONFAM),0)
            FROM   SALDOCONS
            WHERE CDCLIENTE    = @V_CDCLIENTE
              AND CDCONSUMIDOR = @V_CDCONSUMIDOR
              AND CDFAMILISALD = @P_CDFAMILISALD;

            -- INSERE O DBITO REFERENTE A VENDA
            INSERT INTO EXTRATOCONS
              (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS)
            VALUES
              (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,GETDATE(),'001',@V_CDTIPORECE,@P_CDFILIAL,@P_CDCAIXA,@V_NRSEQVENDA,'Venda Caixa'+@P_CDCAIXA,@V_VRMOVEXTCONS,@V_VRSALDCONFAM_CRED-@V_VRMOVEXTCONS,'V',@V_DTABERCAIX,GETDATE(),'N');
            IF @@ERROR <> 0 BEGIN
               SET @V_NRSEQTTEL = SUBSTRING('ERRO INSERT TABELA EXTRATOCONS',1,50);
               SET @V_ERRO      = 'ERRO';
            END;

            SELECT @V_EXISTESALDO = COUNT(*)
            FROM SALDOCONS
            WHERE CDCLIENTE    = @V_CDCLIENTE
              AND CDCONSUMIDOR = @V_CDCONSUMIDOR
              AND CDFAMILISALD = @P_CDFAMILISALD;

            IF @V_EXISTESALDO > 0 BEGIN
               UPDATE SALDOCONS
               SET    VRSALDCONFAM = @V_VRSALDCONFAM_CRED-@V_VRMOVEXTCONS
               WHERE CDCLIENTE    = @V_CDCLIENTE
                 AND CDCONSUMIDOR = @V_CDCONSUMIDOR
                 AND CDFAMILISALD = @P_CDFAMILISALD;
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = 'ERRO UPDATE TABELA EXTRATOCONS';
                  SET @V_ERRO = 'ERRO';
               END;
            END ELSE BEGIN
               INSERT INTO SALDOCONS
                 (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,VRSALDCONFAM)
               VALUES
                 (@V_CDCLIENTE,@V_CDCONSUMIDOR,@P_CDFAMILISALD,0-@V_VRMOVEXTCONS);
               IF @@ERROR <> 0 BEGIN
                  SET @V_NRSEQTTEL = 'ERRO INSERT TABELA EXTRATOCONS';
                  SET @V_ERRO = 'ERRO';
               END;
            END;

         END ELSE BEGIN
            SET @V_NRSEQTTEL = SUBSTRING('SALDO INSUFICIENTE DO CONSUMIDOR',1,50);
            SET @V_ERRO = 'ERRO';
         END;
      END;
   END;

   IF @V_ERRO = 'ERRO' BEGIN
      SET @P_RETORNO = @V_NRSEQTTEL;
      ROLLBACK;
   END ELSE BEGIN
      SET @P_RETORNO = SUBSTRING(@V_NRSEQTTEL,11,10);
      COMMIT;
   END;
END;
GO

BEGIN
DECLARE @RETORNO VARCHAR(50);
EXECUTE GRAVA_VENDA_TTEL '0009','001','1','000000000001','001',1,30,'0000000015',@RETORNO OUTPUT
PRINT @RETORNO
END

BEGIN
DECLARE @RETORNO VARCHAR(50);
EXECUTE GRAVA_VENDA_TTEL '9408','001','0','000000000001','001',1,30,'9610100100',@RETORNO OUTPUT
PRINT @RETORNO
END

